@@ -3,10 +3,10 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2021-07-09
+ *  Updated   : 2021-12-13
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1997-2022 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -2321,12 +2321,6 @@ typedef FILE TCP;
 #	include "nntplib.h"
 #endif /* !NNTPLIB_H */
 
-#ifndef __CPROTO__
-#	ifndef PROTO_H
-#		include "proto.h"
-#	endif /* !PROTO_H */
-#endif /* !__CPROTO__ */
-
 /*
  * rfc1521/rfc1522 interface
  */
@@ -2484,6 +2478,30 @@ extern struct tm *localtime(time_t *);
 #	define UNUSED(x) x
 #endif /* __GNUC__ && !__cplusplus && !__APPLE_CC__ && !__NeXT__ */
 
+/* #if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L */
+#ifdef STDC_NORETURN
+#	ifdef HAVE_STDNORETURN_H
+#		include <stdnoreturn.h>
+#	endif /* HAVE_STDNORETURN_H */
+#else
+#	undef _Noreturn
+#	if defined(__GNUC__) && !defined(__cplusplus) && !defined(__APPLE_CC__) && !defined(__NeXT__)
+#		if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 6)
+#			define _Noreturn __attribute__((noreturn))
+#		else
+#			define _Noreturn /**/
+#		endif /* __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 6) */
+#	else
+#		define _Noreturn /**/
+#	endif /* __GNUC__ && !__cplusplus && !__APPLE_CC__ && !__NeXT__ */
+#endif /* STDC_NORETURN */
+
+#ifndef __CPROTO__
+#	ifndef PROTO_H
+#		include "proto.h"
+#	endif /* !PROTO_H */
+#endif /* !__CPROTO__ */
+
 /* init_selfinfo() needs MM_CHARSET */
 #ifndef MM_CHARSET
 #	define MM_CHARSET "US-ASCII"
