@@ -3,10 +3,10 @@
  *  Module    : init.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2021-02-01
+ *  Updated   : 2021-07-06
  *  Notes     :
  *
- * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2022 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -115,6 +115,7 @@ char userid[PATH_LEN];
 #endif /* !NNTP_ONLY */
 
 t_function last_search = GLOBAL_SEARCH_REPEAT;	/* for repeated search */
+int art_mark_width = 1;
 int hist_last[HIST_MAXNUM + 1];
 int hist_pos[HIST_MAXNUM + 1];
 int iso2asc_supported;			/* Convert ISO-Latin1 to Ascii */
@@ -382,7 +383,6 @@ struct t_config tinrc = {
 	TRUE,		/* show_signatures */
 	TRUE,		/* sigdashes */
 	TRUE,		/* signature_repost */
-	TRUE,		/* start_editor_offset */
 #ifndef USE_CURSES
 	TRUE,		/* strip_blanks */
 #endif /* !USE_CURSES */
@@ -495,7 +495,6 @@ struct t_config tinrc = {
 	TRUE,		/* attrib_show_signatures */
 	TRUE,		/* attrib_sigdashes */
 	TRUE,		/* attrib_signature_repost */
-	TRUE,		/* attrib_start_editor_offset */
 	FALSE,		/* attrib_tex2iso_conv */
 	TRUE,		/* attrib_thread_catchup_on_exit */
 	TRUE,		/* attrib_verbatim_handling */
