@@ -3,7 +3,7 @@
  *  Module    : makecfg.c
  *  Author    : Thomas E. Dickey
  *  Created   : 1997-08-23
- *  Updated   : 2020-08-15
+ *  Updated   : 2021-07-02
  *  Notes     : #defines and structs for options_menu.c
  *
  * Copyright (c) 1997-2021 Thomas E. Dickey <dickey@invisible-island.net>
@@ -171,9 +171,8 @@ index_of(
 	MYDATA *q;
 
 	for (q = all_data; q != NULL && q != p; q = q->link) {
-		if (!strcmp(p->type, q->type)) {
+		if (!strcmp(p->type, q->type))
 			result++;
-		}
 	}
 	return result;
 }
@@ -199,8 +198,14 @@ static const char *
 typename_of(
 	MYDATA *p)
 {
-	if (!strcmp(p->type, "OPT_STRING") || !strcmp(p->type, "OPT_CHAR"))
+	if (!strcmp(p->type, "OPT_STRING"))
 		return "char *";
+	if (!strcmp(p->type, "OPT_CHAR"))
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+		return "wchar_t *";
+#else
+		return "char *";
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 	if (!strcmp(p->type, "OPT_ON_OFF"))
 		return "t_bool *";
 	return "int *";
