@@ -57,7 +57,7 @@ use strict;
 use warnings;
 
 # version Number
-my $version = "1.1.57";
+my $version = "1.1.59";
 
 my %config;
 
@@ -196,6 +196,7 @@ GetOptions('A|V|W|h|headers' => [], # do nothing
 	'from|f=s'	=> \$config{'from'},
 	'ignore-headers|i=s'	=> \$config{'ignore-headers'},
 	'followup-to|w=s'	=> \$config{'followup-to'},
+	'message-id|m=s'	=> \$config{'message-id'},
 	'newsgroups|n=s'	=> \$config{'newsgroups'},
 	'reply-to|r=s'	=> \$config{'reply-to'},
 	'savedir|s=s'	=> \$config{'savedir'},
@@ -347,8 +348,8 @@ foreach ('DISTRIBUTION', 'ORGANIZATION') {
 
 # overwrite headers if specified via cmd-line
 foreach ('Approved', 'Control', 'Distribution', 'Expires',
-	'From', 'Followup-To', 'Newsgroups',' Reply-To', 'Subject',
-	'References', 'Organization', 'Path') {
+	'From', 'Followup-To', 'Message-ID', 'Newsgroups',' Reply-To',
+	'Subject', 'References', 'Organization', 'Path') {
 	next if (!defined($config{lc($_)}));
 	chomp($Header{lc($_)} = $_ . ": " . $config{lc($_)});
 	$Header{lc($_)} .= "\n";
@@ -426,7 +427,7 @@ if (!$config{'nntp-pass'}) {
 }
 
 # instead of abort posting just to prefetch a Messsage-ID we should (try
-# to keep) the the session open instead
+# to) keep the session open instead
 if (!($config{'no-sign'} && $config{'no-canlock'})) {
 	if (! $config{'savedir'} && defined($Header{'newsgroups'}) && !defined($Header{'message-id'})) {
 		my $Server = AuthonNNTP();
@@ -513,6 +514,14 @@ if (! $config{'no-sign'}) {
 	$PGPCommand = getpgpcommand($config{'pgp-version'});
 }
 
+# exit with error if neither $Newsgroups nor any of $To, $Cc or $Bcc are set
+my $required = 0;
+foreach ('Newsgroups', 'To,', 'Cc', 'Bcc') {
+	$required++ if (defined($Header{lc($_)}));
+	last if $required;
+}
+die("$0: neither Newsgroups: nor any of To:, Cc:, or Bcc: present.\n") if (!$required);
+
 # (re)move mail-headers
 my ($To, $Cc, $Bcc, $Newsgroups) = '';
 $To = $Header{'to'} if (defined($Header{'to'}));
@@ -550,14 +559,6 @@ if (($To || $Cc || $Bcc) && $config{'sendmail'}) {
 	close($MAIL);
 }
 
-# exit with error if neither $Newsgroups nor any of $To, $Cc or $Bcc set
-my $required = 0;
-foreach ('Newsgroups', 'To,', 'Cc', 'Bcc') {
-	$required++ if (defined($Header{lc($_)}));
-	last if $required;
-}
-die("$0: neither Newsgroups: nor any of To:, Cc:, Bcc or present.\n") if (!$required);
-
 # Game over. Insert new coin.
 exit;
 
@@ -986,6 +987,7 @@ sub usage {
 	print "  -e string  set Expires:-header to string\n";
 	print "  -f string  set From:-header to string\n";
 	print "  -i string  list of headers to be ignored for signing\n";
+	print "  -m string  set Message-ID:-header to string\n";
 	print "  -n string  set Newsgroups:-header to string\n";
 	print "  -o string  set Organization:-header to string\n";
 	print "  -p port    use port as NNTP port [default=".$config{'nntp-port'}."]\n";
@@ -1087,6 +1089,11 @@ Some of them may be altered on the Server (i.e. Cancel-Key) which would
 invalid the signature, this option can be used the exclude such headers
 if required.
 
+=item -B<m> C<Message-ID> | --B<message-id> C<Message-ID>
+X<-m> X<--message-id>
+
+Set the article header field Message-ID: to the given value.
+
 =item -B<n> C<Newsgroups> | --B<newsgroups> C<Newsgroups>
 X<-n> X<--newsgroups>
 
@@ -1343,7 +1350,7 @@ F<$HOME/.newsauth> is checked first.
 "option=value" configuration pairs, last match counts and only
 "value" is case sensitive. Lines that start with "#" are ignored. If the
 file contains unencrypted passwords (e.g. nntp-pass or pgp-pass), it
-should be readable for the user only. Use -B<vH> to get a dull list of
+should be readable for the user only. Use -B<vH> to get a full list of
 all available configuration options.
 
 =back
@@ -1363,7 +1370,7 @@ B<tinews.pl> is designed to be used with L<pgp(1)>-2.6.3,
 L<pgp(1)>-5, L<pgp(1)>-6, L<gpg(1)> and L<gpg2(1)>.
 
 B<tinews.pl> requires the following standard modules to be installed:
-L<Getopt::Long(3pm)>, L<Net::NNTP(3pm)>, <Time::Local(3pm)> and
+L<Getopt::Long(3pm)>, L<Net::NNTP(3pm)>, L<Time::Local(3pm)> and
 L<Term::Readline(3pm)>.
 
 NNTPS (NNTP with implicit TLS; RFC 4642 and RFC 8143) may be unavailable
